package cn.timer.api.controller.insure;

import java.io.IOException;
import java.util.Map;
import java.util.Optional;
import java.util.Random;

import cn.timer.api.bean.insure.InsureApplicant;
import cn.timer.api.config.annotation.CurrentUser;
import cn.timer.api.config.annotation.UserBean;
import cn.timer.api.dao.insure.InsureApplicantMapper;
import cn.timer.api.dto.insure.InsureDto;
import cn.timer.api.utils.HttpUtils;
import cn.timer.api.utils.Result;
import cn.timer.api.utils.ResultUtil;
import com.alibaba.druid.util.Base64;
import com.alibaba.fastjson.JSONObject;
import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.google.common.collect.Maps;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import io.swagger.models.auth.In;
import org.apache.commons.codec.digest.DigestUtils;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.beans.BeanUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.beans.factory.annotation.Value;
import org.springframework.transaction.annotation.Transactional;
import org.springframework.web.bind.annotation.*;

import org.springframework.web.multipart.MultipartFile;


/**
 * 投保人
 *
 * @author wgd
 * @email 862422848@qq.com
 * @date 2022-03-07 17:02:46
 */
@Api(tags = "23.0保险列表")
@RestController
@Transactional
@RequestMapping(value = "/insureApplicant", produces = {"application/json"})
public class InsureApplicantController {
    private static final Logger log = LoggerFactory.getLogger(InsureApplicantController.class);
    @Autowired
    private InsureApplicantMapper insureApplicantMapper;
    @Value("insure.type.test.appid")
    private String appid;
    @Value("insure.type.test.secret")
    private String secret;

    @Value("insure.type.test.appidq")
    private String appidq;
    @Value("insure.type.test.secretq")
    private String secretq;


    @Value("insure.type.test.uploadUrl")
    private String uploadUrl;
    @Value("insure.type.test.insuredUrl")
    private String insuredUrl;
    @Value("insure.type.test.uploadUrlq")
    private String uploadUrl2;



    @PostMapping("/insureApplicationSetting")
    @ApiOperation(value = "设置投保人", httpMethod = "POST", notes = "投保申请")
    private Result<Object> insureApplicationSetting(@CurrentUser UserBean userBean, @RequestBody InsureApplicant params) {
        InsureApplicant insureApplicant = InsureApplicant.builder().build().selectOne(new QueryWrapper<InsureApplicant>().lambda().eq(InsureApplicant::getOrgCode,userBean.getOrgCode()));
        if(insureApplicant==null){
            params.insert();
            return ResultUtil.data(params);
        }
        BeanUtils.copyProperties(params,insureApplicant);
        insureApplicant.updateById();
        return ResultUtil.data(insureApplicant);
    }


    @PostMapping("/getApplicant")
    @ApiOperation(value = "获取投保人", httpMethod = "POST", notes = "获取投保人")
    private Result<Object> getApplicant(@CurrentUser UserBean userBean) {
        InsureApplicant insureApplicant = InsureApplicant.builder().build().selectOne(new QueryWrapper<InsureApplicant>().lambda().eq(InsureApplicant::getOrgCode,userBean.getOrgCode()));
        if(insureApplicant==null){
            return ResultUtil.data(null);
        }
        return ResultUtil.data(insureApplicant);
    }


    /**
     * 设置链接参数
     *
     * @param sign
     * @return
     */
    private Map setParams(String sign) {
        /*当前时间戳*/
        long timestamp = System.currentTimeMillis()/1000;
        log.info("时间戳" + timestamp);
        Map paramsMap = Maps.newHashMap();
        paramsMap.put("pid", appidq);
        paramsMap.put("timestamp", String.valueOf(timestamp));
        paramsMap.put("trace_id", appidq + timestamp + new Random().nextInt((9999 - 100) + 1) + 10);
//        paramsMap.put("sign",Md5.md5(appid+secret+timestamp+sign.trim()));

        String value = appidq + secretq + timestamp + sign;
        log.info("body参数======" + sign);
        paramsMap.put("sign", DigestUtils.md5Hex(value));
        log.info("params参数======" + JSONObject.toJSONString(paramsMap));
        return paramsMap;
    }

    /**
     * 设置返回信息
     *
     * @param data
     * @return
     */
    private Object message(String data) {
        Map<String, Object> dataMap = JSONObject.parseObject(data);
        if (dataMap.get("errcode").toString().equals("suc")) {
            return dataMap.get("data");
        }
        return dataMap.get("errmsg");
    }
}
